==> gwt-jackson-0.1.0-sources.jar: com/github/nmorel/gwtjackson/client/deser/map/AbstractMapJsonDeserializer.java <==
package com.github.nmorel.gwtjackson.client.deser.map;

import java.util.AbstractMap;
import java.util.LinkedHashMap;

import com.github.nmorel.gwtjackson.client.JsonDeserializer;
import com.github.nmorel.gwtjackson.client.deser.map.BaseMapJsonDeserializer;
import com.github.nmorel.gwtjackson.client.deser.map.key.KeyDeserializer;

/**
 * Default {@link JsonDeserializer} implementation for {@link AbstractMap}. The deserialization process returns a {@link LinkedHashMap}.
 * <p>Cannot be overriden. Use {@link BaseMapJsonDeserializer}.</p>
 *
 * @param <K> Type of the keys inside the {@link AbstractMap}
 * @param <V> Type of the values inside the {@link AbstractMap}
 *
 * @author Nicolas Morel
 */
public final class AbstractMapJsonDeserializer<K, V> extends BaseMapJsonDeserializer<AbstractMap<K, V>, K, V> {

    /**
     * @param keyDeserializer {@link KeyDeserializer} used to deserialize the keys.
     * @param valueDeserializer {@link JsonDeserializer} used to deserialize the values.
     * @param <K> Type of the keys inside the {@link AbstractMap}
     * @param <V> Type of the values inside the {@link AbstractMap}
     *
     * @return a new instance of {@link AbstractMapJsonDeserializer}
     */
    public static <K, V> AbstractMapJsonDeserializer<K, V> newInstance( KeyDeserializer<K> keyDeserializer,
                                                                        JsonDeserializer<V> valueDeserializer ) {
        return new AbstractMapJsonDeserializer<K, V>( keyDeserializer, valueDeserializer );
    }

    /**
     * @param keyDeserializer {@link KeyDeserializer} used to deserialize the keys.
     * @param valueDeserializer {@link JsonDeserializer} used to deserialize the values.
     */
    private AbstractMapJsonDeserializer( KeyDeserializer<K> keyDeserializer, JsonDeserializer<V> valueDeserializer ) {
        super( keyDeserializer, valueDeserializer );
    }

    @Override
    protected AbstractMap<K, V> newMap() {
        return new LinkedHashMap<K, V>();
    }
}

==> gwt-jackson-0.15.4-sources.jar: com/github/nmorel/gwtjackson/client/deser/map/AbstractMapJsonDeserializer.java <==
/*
 * Copyright 2013 Nicolas Morel
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.nmorel.gwtjackson.client.deser.map;

import java.util.AbstractMap;
import java.util.LinkedHashMap;

import com.github.nmorel.gwtjackson.client.JsonDeserializer;
import com.github.nmorel.gwtjackson.client.deser.map.key.KeyDeserializer;

/**
 * Default {@link JsonDeserializer} implementation for {@link AbstractMap}. The deserialization process returns a {@link LinkedHashMap}.
 * <p>Cannot be overriden. Use {@link BaseMapJsonDeserializer}.</p>
 *
 * @param <K> Type of the keys inside the {@link AbstractMap}
 * @param <V> Type of the values inside the {@link AbstractMap}
 * @author Nicolas Morel
 * @version $Id: $
 */
public final class AbstractMapJsonDeserializer<K, V> extends BaseMapJsonDeserializer<AbstractMap<K, V>, K, V> {

    /**
     * <p>newInstance</p>
     *
     * @param keyDeserializer {@link KeyDeserializer} used to deserialize the keys.
     * @param valueDeserializer {@link JsonDeserializer} used to deserialize the values.
     * @param <K> Type of the keys inside the {@link AbstractMap}
     * @param <V> Type of the values inside the {@link AbstractMap}
     * @return a new instance of {@link AbstractMapJsonDeserializer}
     */
    public static <K, V> AbstractMapJsonDeserializer<K, V> newInstance( KeyDeserializer<K> keyDeserializer,
                                                                        JsonDeserializer<V> valueDeserializer ) {
        return new AbstractMapJsonDeserializer<K, V>( keyDeserializer, valueDeserializer );
    }

    /**
     * @param keyDeserializer {@link KeyDeserializer} used to deserialize the keys.
     * @param valueDeserializer {@link JsonDeserializer} used to deserialize the values.
     */
    private AbstractMapJsonDeserializer( KeyDeserializer<K> keyDeserializer, JsonDeserializer<V> valueDeserializer ) {
        super( keyDeserializer, valueDeserializer );
    }

    /** {@inheritDoc} */
    @Override
    protected AbstractMap<K, V> newMap() {
        return new LinkedHashMap<K, V>();
    }
}
